==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/metrics/v1beta1/PodMetricsOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.metrics.v1beta1.DoneablePodMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.PodMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.PodMetricsList;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.DoneablePodMetrics;

import java.util.Map;
import java.util.TreeMap;


public class PodMetricsOperationsImpl extends HasMetadataOperation<PodMetrics, PodMetricsList, DoneablePodMetrics, Resource<PodMetrics, DoneablePodMetrics>> {

  public PodMetricsOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public PodMetricsOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public PodMetricsOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("metrics.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("podmetrics"));
    this.type = PodMetrics.class;
    this.listType = PodMetricsList.class;
    this.doneableType = DoneablePodMetrics.class;
  }

  public PodMetricsOperationsImpl newInstance(OperationContext context) {
    return new PodMetricsOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.3.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/metrics/v1beta1/PodMetricsOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.metrics.v1beta1.PodMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.PodMetricsBuilder;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.PodMetricsList;

import java.util.Map;
import java.util.TreeMap;


public class PodMetricsOperationsImpl extends HasMetadataOperation<PodMetrics, PodMetricsList, Resource<PodMetrics>> {

  public PodMetricsOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public PodMetricsOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public PodMetricsOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("metrics.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("podmetrics"));
    this.type = PodMetrics.class;
    this.listType = PodMetricsList.class;
  }

  public PodMetricsOperationsImpl newInstance(OperationContext context) {
    return new PodMetricsOperationsImpl(context);
  }

  @Override
  public PodMetrics edit(Visitor... visitors) {
    return patch(new PodMetricsBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
